@@ -1,15 +1,10 @@
-"""This module trys to support builtin types and functions."""
+"""This module tries to support builtin types and functions."""
+
 import inspect
 import io
 
-try:
-    raw_input
-except NameError:
-    raw_input = input
-
 import rope.base.evaluate
-from rope.base.utils import pycompat
-from rope.base import pynames, pyobjects, arguments, utils
+from rope.base import arguments, ast, pynames, pyobjects, utils
 
 
 class BuiltinModule(pyobjects.AbstractModule):
@@ -720,15 +715,11 @@ class Lambda(pyobjects.AbstractFunction):
         return "lambda"
 
     def get_param_names(self, special_args=True):
-        result = [
-            pycompat.get_ast_arg_arg(node)
-            for node in self.arguments.args
-            if isinstance(node, pycompat.ast_arg_type)
-        ]
+        result = [node.arg for node in self.arguments.args if isinstance(node, ast.arg)]
         if self.arguments.vararg:
-            result.append("*" + pycompat.get_ast_arg_arg(self.arguments.vararg))
+            result.append("*" + self.arguments.vararg.arg)
         if self.arguments.kwarg:
-            result.append("**" + pycompat.get_ast_arg_arg(self.arguments.kwarg))
+            result.append("**" + self.arguments.kwarg.arg)
         return result
 
     @property
@@ -845,9 +836,7 @@ _initial_builtins = {
     "tuple": BuiltinName(get_tuple_type()),
     "set": BuiltinName(get_set_type()),
     "str": BuiltinName(get_str_type()),
-    "file": BuiltinName(get_file_type()),
     "open": BuiltinName(BuiltinFunction(function=_open_function, builtin=open)),
-    "unicode": BuiltinName(get_str_type()),
     "range": BuiltinName(BuiltinFunction(function=_range_function, builtin=range)),
     "reversed": BuiltinName(
         BuiltinFunction(function=_reversed_function, builtin=reversed)
@@ -864,9 +853,7 @@ _initial_builtins = {
     "object": BuiltinName(BuiltinObject()),
     "type": BuiltinName(BuiltinType()),
     "iter": BuiltinName(BuiltinFunction(function=_iter_function, builtin=iter)),
-    "raw_input": BuiltinName(
-        BuiltinFunction(function=_input_function, builtin=raw_input)
-    ),
+    "input": BuiltinName(BuiltinFunction(function=_input_function, builtin=input)),
 }
 
-builtins = BuiltinModule(pycompat.builtins.__name__, initial=_initial_builtins)
+builtins = BuiltinModule("builtins", initial=_initial_builtins)
