@@ -1,5 +1,4 @@
-class IResolver(object):
-
+class IResolver:
     def __call__(self, hint, pyobject):
         """
         :param hint: For example "List[int]" or "(Foo, Bar) -> Baz" or simple "Foo"
