@@ -1,18 +1,16 @@
+from __future__ import annotations
+
 import logging
+import sys
+from typing import TYPE_CHECKING, Optional, Union
 
-try:
-    from typing import Union, Optional
-except ImportError:
-    pass
 import rope.base.utils as base_utils
-from rope.base.evaluate import ScopeNameFinder
+from rope.base import evaluate
 from rope.base.exceptions import AttributeNotFoundError
 from rope.base.pyobjects import PyClass, PyDefinedObject, PyFunction, PyObject
-from rope.base.utils import pycompat
 
 
 def get_super_func(pyfunc):
-
     if not isinstance(pyfunc.parent, PyClass):
         return
 
@@ -77,16 +75,24 @@ def get_mro(pyclass):
     return class_list
 
 
-def resolve_type(type_name, pyobject):
-    # type: (str, Union[PyDefinedObject, PyObject]) -> Optional[PyDefinedObject, PyObject]
+def resolve_type(
+    type_name: str,
+    pyobject: Union[PyDefinedObject, PyObject],
+) -> Optional[Union[PyDefinedObject, PyObject]]:
     """
     Find proper type object from its name.
     """
-    deprecated_aliases = {"collections": "collections.abc"}
+    if sys.version_info < (3, 13):
+        deprecated_aliases = {"collections": "collections.abc"}
+    else:
+        deprecated_aliases = {"collections": "_collections_abc"}
     ret_type = None
     logging.debug("Looking for %s", type_name)
     if "." not in type_name:
         try:
+            # XXX: this looks incorrect? It doesn't seem like it would work
+            # correctly if you have a type/class not defined in the
+            # module/global scope
             ret_type = (
                 pyobject.get_module().get_scope().get_name(type_name).get_object()
             )
@@ -95,7 +101,7 @@ def resolve_type(type_name, pyobject):
     else:
         mod_name, attr_name = type_name.rsplit(".", 1)
         try:
-            mod_finder = ScopeNameFinder(pyobject.get_module())
+            mod_finder = evaluate.ScopeNameFinder(pyobject.get_module())
             mod = mod_finder._find_module(mod_name).get_object()
             ret_type = mod.get_attribute(attr_name).get_object()
         except AttributeNotFoundError:
@@ -117,7 +123,6 @@ def resolve_type(type_name, pyobject):
 
 
 class ParametrizeType:
-
     _supported_mapping = {
         "builtins.list": "rope.base.builtins.get_list",
         "builtins.tuple": "rope.base.builtins.get_tuple",
@@ -128,18 +133,6 @@ class ParametrizeType:
         "collections.abc.Iterable": "rope.base.builtins.get_iterator",  # Python3.3
         "collections.abc.Iterator": "rope.base.builtins.get_iterator",  # Python3.3
     }
-    if pycompat.PY2:
-        _supported_mapping = dict(
-            (
-                (
-                    k.replace("builtins.", "__builtin__.").replace(
-                        "_collections_abc.", "_abcoll."
-                    ),
-                    v,
-                )
-                for k, v in _supported_mapping.items()
-            )
-        )
 
     def __call__(self, pyobject, *args, **kwargs):
         """
