@@ -1,23 +1,38 @@
 """AutoImport module for rope."""
 
+from __future__ import annotations
+
 import contextlib
 import json
 import re
+import secrets
 import sqlite3
 import sys
 import warnings
 from collections import OrderedDict
 from concurrent.futures import Future, ProcessPoolExecutor, as_completed
 from datetime import datetime
+from hashlib import sha256
 from itertools import chain
 from pathlib import Path
-from typing import Generator, Iterable, Iterator, List, Optional, Set, Tuple
+from threading import local
+from typing import (
+    Generator,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Set,
+    Tuple,
+    TYPE_CHECKING,
+)
 
 from rope.base import exceptions, libutils, resourceobserver, taskhandle, versioning
 from rope.base.project import Project
 from rope.base.resources import Resource
 from rope.contrib.autoimport import models
 from rope.contrib.autoimport.defs import (
+    Alias,
     ModuleFile,
     Name,
     NameType,
@@ -37,9 +52,13 @@ from rope.contrib.autoimport.utils import (
 from rope.refactor import importutils
 
 
+if TYPE_CHECKING:
+    from collections.abc import Collection
+
+
 def get_future_names(
     packages: List[Package], underlined: bool, job_set: taskhandle.BaseJobSet
-) -> Generator[Future, None, None]:
+) -> Generator[Future[Collection[Name]], None, None]:
     """Get all names as futures."""
     with ProcessPoolExecutor() as executor:
         for package in packages:
@@ -77,10 +96,10 @@ class AutoImport:
 
     """
 
-    connection: sqlite3.Connection
-    underlined: bool
+    memory: bool
     project: Project
     project_package: Package
+    underlined: bool
 
     def __init__(
         self,
@@ -109,13 +128,14 @@ class AutoImport:
                 autoimport = AutoImport(..., memory=True)
         """
         self.project = project
-        project_package = get_package_tuple(Path(project.root.real_path), project)
+        project_package = get_package_tuple(project.root.pathlib, project)
         assert project_package is not None
         assert project_package.path is not None
         self.project_package = project_package
         self.underlined = underlined
+        self.memory = memory
         if memory is _deprecated_default:
-            memory = True
+            self.memory = True
             warnings.warn(
                 "The default value for `AutoImport(memory)` argument will "
                 "change to use an on-disk database by default in the future. "
@@ -123,6 +143,7 @@ class AutoImport:
                 "`AutoImport(memory=True)` explicitly.",
                 DeprecationWarning,
             )
+        self.thread_local = local()
         self.connection = self.create_database_connection(
             project=project,
             memory=memory,
@@ -149,14 +170,45 @@ class AutoImport:
         memory : bool
             if true, don't persist to disk
         """
+
+        def calculate_project_hash(data: str) -> str:
+            return sha256(data.encode()).hexdigest()
+
         if not memory and project is None:
             raise Exception("if memory=False, project must be provided")
-        db_path: str
         if memory or project is None or project.ropefolder is None:
-            db_path = ":memory:"
+            # Allows the in-memory db to be shared across threads
+            # See https://www.sqlite.org/inmemorydb.html
+            project_hash: str
+            if project is None:
+                project_hash = secrets.token_hex()
+            elif project.ropefolder is None:
+                project_hash = calculate_project_hash(project.address)
+            else:
+                project_hash = calculate_project_hash(project.ropefolder.real_path)
+            return sqlite3.connect(
+                f"file:rope-{project_hash}:?mode=memory&cache=shared", uri=True
+            )
         else:
-            db_path = str(Path(project.ropefolder.real_path) / "autoimport.db")
-        return sqlite3.connect(db_path)
+            return sqlite3.connect(project.ropefolder.pathlib / "autoimport.db")
+
+    @property
+    def connection(self) -> sqlite3.Connection:
+        """
+        Creates a new connection if called from a new thread.
+
+        This makes sure AutoImport can be shared across threads.
+        """
+        if not hasattr(self.thread_local, "connection"):
+            self.thread_local.connection = self.create_database_connection(
+                project=self.project,
+                memory=self.memory,
+            )
+        return self.thread_local.connection
+
+    @connection.setter
+    def connection(self, value: sqlite3.Connection):
+        self.thread_local.connection = value
 
     def _setup_db(self):
         models.Metadata.create_table(self.connection)
@@ -293,11 +345,18 @@ class AutoImport:
             yield SearchResult(
                 f"import {module}", module, source, NameType.Module.value
             )
+        for alias, module, source in self._execute(
+            models.Alias.search_modules_with_alias.select("alias", "module", "source"),
+            (name,),
+        ):
+            yield SearchResult(
+                f"import {module} as {alias}", alias, source, NameType.Module.value
+            )
 
     def get_modules(self, name) -> List[str]:
         """Get the list of modules that have global `name`."""
         results = self._execute(
-            models.Name.search_by_name_like.select("module", "source"), (name,)
+            models.Name.search_by_name.select("module", "source"), (name,)
         ).fetchall()
         return sort_and_deduplicate(results)
 
@@ -434,11 +493,14 @@ class AutoImport:
         """
         with self.connection:
             self._execute(models.Name.objects.drop_table())
+            self._execute(models.Alias.objects.drop_table())
             self._execute(models.Package.objects.drop_table())
             self._execute(models.Metadata.objects.drop_table())
             models.Name.create_table(self.connection)
+            models.Alias.create_table(self.connection)
             models.Package.create_table(self.connection)
             models.Metadata.create_table(self.connection)
+            self.add_aliases(self.project.prefs.autoimport.aliases)
             data = (
                 versioning.calculate_version_hash(self.project),
                 json.dumps(versioning.get_version_hash_data(self.project)),
@@ -503,17 +565,29 @@ class AutoImport:
             return folder.is_dir() and folder.as_posix() != "/usr/bin"
 
         folders = self.project.get_python_path_folders()
-        folder_paths = map(lambda folder: Path(folder.real_path), folders)
-        folder_paths = filter(filter_folders, folder_paths)  # type:ignore
+        folder_paths = filter(filter_folders, map(Path, folders))
         return list(OrderedDict.fromkeys(folder_paths))
 
+    def _safe_iterdir(self, folder: Path):
+        try:
+            dirs = folder.iterdir()
+            while True:
+                try:
+                    yield next(dirs)
+                except PermissionError:
+                    pass
+                except StopIteration:
+                    break
+        except PermissionError:
+            pass
+
     def _get_available_packages(self) -> List[Package]:
         packages: List[Package] = [
             Package(module, Source.BUILTIN, None, PackageType.BUILTIN)
             for module in sys.builtin_module_names
         ]
         for folder in self._get_python_folders():
-            for package in folder.iterdir():
+            for package in self._safe_iterdir(folder):
                 package_tuple = get_package_tuple(package, self.project)
                 if package_tuple is None:
                     continue
@@ -536,9 +610,6 @@ class AutoImport:
             modname = self._resource_to_module(resource).modname
             self._del_if_exist(modname)
 
-    def _add_future_names(self, names: Future):
-        self._add_names(names.result())
-
     @staticmethod
     def _convert_name(name: Name) -> tuple:
         return (
@@ -549,8 +620,12 @@ class AutoImport:
             name.name_type.value,
         )
 
-    def _add_names(self, names: Iterable[Name]):
-        if names is not None:
+    def add_aliases(self, aliases: Collection[Alias]):
+        if aliases:
+            self._executemany(models.Alias.objects.insert_into(), aliases)
+
+    def _add_names(self, names: Collection[Name]):
+        if names:
             self._executemany(
                 models.Name.objects.insert_into(),
                 [self._convert_name(name) for name in names],
@@ -563,7 +638,7 @@ class AutoImport:
         if target_name in sys.builtin_module_names:
             return Package(target_name, Source.BUILTIN, None, PackageType.BUILTIN)
         for folder in self._get_python_folders():
-            for package in folder.iterdir():
+            for package in self._safe_iterdir(folder):
                 package_tuple = get_package_tuple(package, self.project)
                 if package_tuple is None:
                     continue
@@ -578,7 +653,7 @@ class AutoImport:
     ) -> ModuleFile:
         assert self.project_package.path
         underlined = underlined if underlined else self.underlined
-        resource_path: Path = Path(resource.real_path)
+        resource_path: Path = resource.pathlib
         # The project doesn't need its name added to the path,
         # since the standard python file layout accounts for that
         # so we set add_package_name to False
