@@ -1,13 +1,9 @@
+import unittest
 from textwrap import dedent
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 from rope.base import builtins, libutils, pyobjects
-from ropetest import testutils
 from rope.base.builtins import Dict
+from ropetest import testutils
 
 
 class BuiltinTypesTest(unittest.TestCase):
