@@ -1,12 +1,8 @@
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
+import unittest
 
+import rope.base.change
 import rope.base.history
 import rope.contrib.changestack
-import rope.base.change
 from ropetest import testutils
 
 
