@@ -1,13 +1,9 @@
+import unittest
 from textwrap import dedent
 
 from rope.refactor import restructure
 from ropetest import testutils
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 
 class RestructureTest(unittest.TestCase):
     def setUp(self):
