@@ -1,10 +1,6 @@
+import unittest
 from textwrap import dedent
 
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
-
 from rope.base import ast
 from rope.refactor import suites
 from ropetest import testutils
