@@ -1,29 +1,22 @@
+import logging
 import os.path
 import shutil
 import sys
-import logging
-
-logging.basicConfig(format="%(levelname)s:%(funcName)s:%(message)s", level=logging.INFO)
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import tempfile
+import unittest
+from pathlib import Path
 
 import rope.base.project
 from rope.contrib import generate
 
+logging.basicConfig(format="%(levelname)s:%(funcName)s:%(message)s", level=logging.INFO)
 
-def sample_project(root=None, foldername=None, **kwds):
-    if root is None:
-        root = "sample_project"
-        if foldername:
-            root = foldername
-        # HACK: Using ``/dev/shm/`` for faster tests
-        if os.name == "posix":
-            if os.path.isdir("/dev/shm") and os.access("/dev/shm", os.W_OK):
-                root = "/dev/shm/" + root
-            elif os.path.isdir("/tmp") and os.access("/tmp", os.W_OK):
-                root = "/tmp/" + root
+RUN_TMP_DIR = tempfile.mkdtemp(prefix="ropetest-run-")
+
+
+def sample_project(foldername=None, **kwds):
+    root = Path(tempfile.mkdtemp(prefix="project-", dir=RUN_TMP_DIR))
+    root /= foldername if foldername else "sample_project"
     logging.debug("Using %s as root of the project.", root)
     # Using these prefs for faster tests
     prefs = {
@@ -35,7 +28,6 @@ def sample_project(root=None, foldername=None, **kwds):
         "import_dynload_stdmods": False,
     }
     prefs.update(kwds)
-    remove_recursively(root)
     project = rope.base.project.Project(root, **prefs)
     return project
 
@@ -84,7 +76,7 @@ def only_for(version):
     """Should be used as a decorator for a unittest.TestCase test method"""
     return unittest.skipIf(
         sys.version_info < parse_version(version),
-        "This test requires at least {0} version of Python.".format(version),
+        f"This test requires at least {version} version of Python.",
     )
 
 
@@ -92,7 +84,7 @@ def only_for_versions_lower(version):
     """Should be used as a decorator for a unittest.TestCase test method"""
     return unittest.skipIf(
         sys.version_info > parse_version(version),
-        "This test requires version of Python lower than {0}".format(version),
+        f"This test requires version of Python lower than {version}",
     )
 
 
@@ -100,7 +92,7 @@ def only_for_versions_higher(version):
     """Should be used as a decorator for a unittest.TestCase test method"""
     return unittest.skipIf(
         sys.version_info < parse_version(version),
-        "This test requires version of Python higher than {0}".format(version),
+        f"This test requires version of Python higher than {version}",
     )
 
 
